"""Fedora logo"""

from archey.colors import Colors

COLORS = [Colors.BLUE_BRIGHT, Colors.BLUE_NORMAL, Colors.WHITE_BRIGHT]

# pylint: disable=line-too-long
LOGO = [
    """{c[0]}              {c[1]}........{c[0]}             """,
    """{c[0]}          {c[1]}.::::::::::::::.{c[0]}         """,
    """{c[0]}       {c[1]}.::::::::::::::::::::.{c[0]}      """,
    """{c[0]}     {c[1]}.::::::::::::{c[2]}.shhdhyo.{c[1]}:::.{c[0]}    """,
    """{c[0]}   {c[1]}.::::::::::::{c[2]}omMMMNNNMMMP){c[1]}:::.{c[0]}  """,
    """{c[0]}  {c[1]}.::::::::::::{c[2]}sMMMdo:'{c[0]}+++++++{c[1]}:::.{c[0]} """,
    """{c[0]}  {c[1]}:::::::::::::{c[2]}MMMd{c[1]}:::::::{c[0]}+++++{c[1]}:::{c[0]} """,
    """{c[0]} {c[1]}::::::::::::::{c[2]}MMMy{c[1]}:::::::{c[0]}+++++{c[1]}::::{c[0]}""",
    """{c[0]} {c[1]}:::::::{c[0]}++++++{c[1]}{c[2]}/+MMMh\\{c[1]}::{c[0]}+++++++{c[1]}:::::{c[0]}""",
    """{c[0]} {c[1]}::::{c[0]}+++++{c[2]}oNMMMMMMMMMNho{c[0]}+++++{c[1]}::::::{c[0]}""",
    """{c[0]} {c[1]}:::{c[0]}+++++{c[1]}::{c[2]}shhhMMMmhhy{c[0]}+++++{c[1]}::::::::{c[0]}""",
    """{c[0]} {c[1]}::{c[0]}++++++{c[1]}::::::{c[2]}MMMy{c[1]}:::::::::::::::{c[0]} """,
    """{c[0]} {c[1]}::{c[0]}+++++{c[1]}::::::{c[2]}.MMMy{c[1]}::::::::::::::'{c[0]} """,
    """{c[0]} {c[1]}::{c[0]}++++++{c[1]}::::{c[2]}.hMMM+{c[1]}:::::::::::::'{c[0]}  """,
    """{c[0]} {c[1]}::::{c[2]}dMMNdyydNMMNo{c[1]}::::::::::::'{c[0]}    """,
    """{c[0]} {c[1]}:::::{c[2]}sdNMMMMNds{c[1]}::::::::::::'{c[0]}      """,
    """{c[0]} {c[1]}::::::::{c[2]}'YY'{c[1]}::::::::::::'{c[0]}         """,
    """{c[0]} {c[1]}\\:::::::::::::::::'''{c[0]}             """,
]
